@@ -69,10 +69,10 @@ bool WStringToDouble(const std::wstring& string, double& value)
 
 Settings::Settings()
 : okAction(new Lum::Model::Action()),
-  choice(new Lum::Model::SizeT()),
+  choice(new Lum::Model::ULong()),
   choices(new Lum::Model::StringTable()),
-  setting(new Lum::Model::SizeT()),
-  preset(new Lum::Model::SizeT()),
+  setting(new Lum::Model::ULong()),
+  preset(new Lum::Model::ULong()),
   presets(new Lum::Model::StringTable()),
   factor(new Lum::Model::String(L"")),
   unit(new Lum::Model::String(L"")),
